==> nextcloud-18.0.4.tar.bz2: nextcloud/apps/updatenotification/l10n/lt_LT.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Yra prieinama {version}. Gaukite daugiau informacijos apie tai kaip atnaujinti.",
    "Channel updated" : "Kanalas atnaujintas",
    "Update notifications" : "Atnaujinimų pranešimai",
    "The update server could not be reached since %d days to check for new updates." : " Atnaujinimo serveris nepasiekiamas  %d dienas.",
    "Please check the Nextcloud and server log files for errors." : "Prašome patikrinti Nextcloud ir serverio žurnalų įrašus apie galimas klaidas.",
    "Update to %1$s is available." : "Yra prieinamas atnaujinimas į %1$s.",
    "Update for %1$s to version %2$s is available." : "Yra prieinamas %1$s atnaujinimas į versiją %2$s.",
    "Update for {app} to version %s is available." : "Yra prieinamas {app} atnaujinimas į versiją %s.",
    "Update notification" : "Atnaujinimų pranešimas",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Jūsų naudojama versija daugiau nebeprižiūrima. Esant galimybei, kaip įmanoma greičiau atnaujinkite į palaikomą versiją.",
    "Apps missing updates" : "Programėlės, kurioms trūksta atnaujinimų",
    "View in store" : "Rodyti parduotuvėje",
    "Apps with available updates" : "Programėlės su prieinamais atnaujinimais",
    "Open updater" : "Atverti atnaujinimo programą",
    "Download now" : "Atsisiųsti dabar",
    "What's new?" : "Kas naujo?",
    "The update check is not yet finished. Please refresh the page." : "Atnaujinimų patikrinimas dar neužbaigtas. Prašome įkelti puslapį iš naujo.",
    "Your version is up to date." : "Jūsų versija yra naujausia.",
    "A non-default update server is in use to be checked for updates:" : "Atnaujinimų tikrinimui yra naudojamas ne numatytasis atnaujinimų serveris: ",
    "Update channel:" : "Atnaujinimo kanalas:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Visada galite atnaujinti į naujesnę versiją. Tačiau niekada negalite sendinti į stabilesnę versiją.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Turėkite omenyje, kad po naujos versijos išleidimo, gali praeiti šiek tiek laiko, kol ji čia taps matoma. Mes išleidžiame naujas versijas paskirstytas pagal laiką savo naudotojams ir, kartais, pastebėjus klaidas, praleidžiame versiją.",
    "Notify members of the following groups about available updates:" : "Apie galimus atnaujinimus informuoti narius iš grupių:",
    "Only notification for app updates are available." : "Yra prieinami tik pranešimai apie programėlių atnaujinimus.",
    "The selected update channel does not support updates of the server." : "Pasirinktas kanalas nepalaiko serverio atnaujinimų.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Yra prieinama nauja versija: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Tikrinta {lastCheckedDate}",
    "Checking apps for compatible updates" : "Tikrinama, ar yra suderinamų programėlių atnaujinimų",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Įsitikinkite, kad jūsų config.php nenustato <samp>appstoreenabled</samp> į neigiamą reikšmę.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Nepavyko prisijungti prie programėlių parduotuvės arba programėlių parduotuvė negrąžino visiškai jokių atnaujinimų. Atlikite rankinę atnaujinimų paiešką arba įsitikinkite, kad jūsų serveris turi prieigą prie interneto ir gali prisijungti prie programėlių parduotuvės.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Visos</strong> programėlės turi šiai versijai prieinamą atnaujinimą",
    "View changelog" : "Rodyti keitinių žurnalą",
    "Stable" : "Stabilus",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Paskiausia stabili versija. Tinka įprastam naudojimui ir visada bus atnaujinama į naujausią pagrindinę versiją.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Išankstinės laidos versija, skirta tik naujų ypatybių išbandymui, o ne darbinėms aplinkoms.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> programėlė neturi šiai versijai prieinamo atnaujinimo","<strong>%n</strong> programėlės neturi šiai versijai prieinamo atnaujinimo","<strong>%n</strong> programėlių neturi šiai versijai prieinamo atnaujinimo","<strong>%n</strong> programėlė neturi šiai versijai prieinamo atnaujinimo"]
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-29.0.7.tar.bz2: nextcloud/apps/updatenotification/l10n/lt_LT.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Yra prieinama {version}. Gaukite daugiau informacijos apie tai, kaip atnaujinti.",
    "Channel updated" : "Kanalas atnaujintas",
    "Update notifications" : "Atnaujinimų pranešimai",
    "The update server could not be reached since %d days to check for new updates." : " Atnaujinimo serveris nepasiekiamas  %d dienas.",
    "Please check the Nextcloud and server log files for errors." : "Prašome patikrinti Nextcloud ir serverio žurnalų įrašus apie galimas klaidas.",
    "Update to {serverAndVersion} is available." : "Yra prieinamas atnaujinimas į {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Yra prieinamas {app} atnaujinimas į versiją %s.",
    "Update notification" : "Atnaujinimų pranešimas",
    "Update" : "Atnaujinti",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Jūsų naudojama versija daugiau nebeprižiūrima. Esant galimybei, kaip įmanoma greičiau atnaujinkite į palaikomą versiją.",
    "Apps missing compatible version" : "Programėlės be suderinamos versijos",
    "View in store" : "Rodyti parduotuvėje",
    "Apps with compatible version" : "Programėlės su suderinama versija",
    "Open updater" : "Atverti atnaujinimo programą",
    "Download now" : "Atsisiųsti dabar",
    "What's new?" : "Kas naujo?",
    "View changelog" : "Rodyti keitinių žurnalą",
    "The update check is not yet finished. Please refresh the page." : "Atnaujinimų patikrinimas dar neužbaigtas. Prašome įkelti puslapį iš naujo.",
    "Your version is up to date." : "Jūsų versija yra naujausia.",
    "A non-default update server is in use to be checked for updates:" : "Atnaujinimų tikrinimui yra naudojamas ne numatytasis atnaujinimų serveris: ",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Visada galite atnaujinti į naujesnę versiją. Tačiau niekada negalite sendinti į stabilesnę versiją.",
    "Notify members of the following groups about available updates:" : "Apie galimus atnaujinimus informuoti narius iš grupių:",
    "Only notifications for app updates are available." : "Yra prieinami tik pranešimai apie programėlių atnaujinimus.",
    "The selected update channel does not support updates of the server." : "Pasirinktas kanalas nepalaiko serverio atnaujinimų.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Yra prieinama nauja versija: <strong>{newVersionString}</strong>",
    "Checking apps for compatible versions" : "Tikrinamos suderinamos programėlių versijos",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Įsitikinkite, kad jūsų config.php nenustato <samp>appstoreenabled</samp> į neigiamą reikšmę.",
    "Stable" : "Stabilus",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Paskiausia stabili versija. Tinka įprastam naudojimui ir visada bus atnaujinama į naujausią pagrindinę versiją.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Išankstinės laidos versija, skirta tik naujų ypatybių išbandymui, o ne darbinėms aplinkoms.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> programėlė neturi su šia Nextcloud versija suderinamos versijos.","<strong>%n</strong> programėlės neturi su šia Nextcloud versija suderinamų versijų.","<strong>%n</strong> programėlių neturi su šia Nextcloud versija suderinamų versijų.","<strong>%n</strong> programėlė neturi su šia Nextcloud versija suderinamų versijų."],
    "Update to %1$s is available." : "Yra prieinamas atnaujinimas į %1$s."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
